@@ -21,6 +21,7 @@
  */
 
 #include <config.h>
+#include <glib.h>
 #include <string.h>
 #include <math.h>
 #include <sys/types.h>
@@ -125,13 +126,13 @@ get_full_uri (DlgNewData *data)
 
         uri_ext = get_archive_filename_extension (uri);
         default_ext = mime_type_desc[data->supported_types[idx-1]].default_ext;
-        if (strcmp_null_tolerant (uri_ext, default_ext) != 0) {
+        if (strcmp_null_tolerant (uri_ext, default_ext) != 0)
             full_uri = g_strconcat (uri, default_ext, NULL);
-            g_free (uri);
-        }
     }
     if (full_uri == NULL)
         full_uri = uri;
+    else
+        g_free (uri);
 
     return full_uri;
 }
@@ -382,8 +383,8 @@ activate_action_open (GtkAction *action,
     file_sel = gtk_file_chooser_dialog_new (_("Open"),
                         GTK_WINDOW (window),
                         GTK_FILE_CHOOSER_ACTION_OPEN,
-                        GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                        GTK_STOCK_OPEN, GTK_RESPONSE_OK,
+                        "gtk-cancel", GTK_RESPONSE_CANCEL,
+                        "gtk-open", GTK_RESPONSE_OK,
                         NULL);
     gtk_dialog_set_default_response (GTK_DIALOG (file_sel), GTK_RESPONSE_OK);
     gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (file_sel), FALSE);
@@ -841,16 +842,14 @@ activate_action_manual (GtkAction *action,
 }
 
 
+#define ABOUT_GROUP "About"
+#define EMAILIFY(string) (g_strdelimit ((string), "%", '@'))
+
 void
 activate_action_about (GtkAction *action,
-               gpointer   data)
+               gpointer   gp)
 {
-    FrWindow *window = data;
-    const char *authors[] = {
-        "Paolo Bacchilega <paolo.bacchilega@libero.it>",
-        "Perberos <perberos@gmail.com>",
-        NULL
-    };
+    FrWindow *window = gp;
     const char *documenters [] = {
         "Alexander Kirillov",
         "Breda McColgan",
@@ -870,13 +869,36 @@ activate_action_about (GtkAction *action,
         "51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA")
     };
     char *license_text;
+    GKeyFile *key_file;
+    GBytes *bytes;
+    const guint8 *data;
+    gsize data_len;
+    GError *error = NULL;
+    char **authors;
+    gsize n_authors = 0, i;
+
+    bytes = g_resources_lookup_data (ENGRAMPA_RESOURCE_UI_PATH G_DIR_SEPARATOR_S "engrampa.about", G_RESOURCE_LOOKUP_FLAGS_NONE, &error);
+    g_assert_no_error (error);
+
+    data = g_bytes_get_data (bytes, &data_len);
+    key_file = g_key_file_new ();
+    g_key_file_load_from_data (key_file, (const char *) data, data_len, 0, &error);
+    g_assert_no_error (error);
+
+    authors = g_key_file_get_string_list (key_file, ABOUT_GROUP, "Authors", &n_authors, NULL);
+
+    g_key_file_free (key_file);
+    g_bytes_unref (bytes);
+
+    for (i = 0; i < n_authors; ++i)
+        authors[i] = EMAILIFY (authors[i]);
 
     license_text =  g_strjoin ("\n\n", _(license[0]), _(license[1]), _(license[2]), NULL);
 
     gtk_show_about_dialog (GTK_WINDOW (window),
                    "version", VERSION,
                    "copyright", _("Copyright \xc2\xa9 2001–2010 Free Software Foundation, Inc.\n"
-                                  "Copyright \xc2\xa9 2012–2018 The MATE developers"),
+                                  "Copyright \xc2\xa9 2012–2019 The MATE developers"),
                    "comments", _("An archive manager for MATE."),
                    "authors", authors,
                    "documenters", documenters,
@@ -887,5 +909,6 @@ activate_action_about (GtkAction *action,
                    "website", "http://mate-desktop.org",
                    NULL);
 
+    g_strfreev (authors);
     g_free (license_text);
 }
