@@ -588,13 +588,24 @@ const char *sevenz_mime_types[] = { "application/x-7z-compressed",
 				    "application/x-ms-dos-executable",
 				    "application/x-ms-wim",
 				    "application/x-rar",
-				    "application/zip",
-				    NULL };
+				    "application/zip", /* zip always at the end and the number of */
+				    NULL };            /* place in fr_command_7z_get_mime_types   */
 
 
 static const char **
 fr_command_7z_get_mime_types (FrCommand *comm)
 {
+	GSettings *settings;
+	settings = g_settings_new ("org.mate.engrampa.general");
+
+	if (g_settings_get_boolean (settings, "unar-open-zip") &&
+	    is_program_in_path ("unar") && is_program_in_path ("lsar"))
+		sevenz_mime_types [8] = NULL;
+	else
+		g_settings_set_boolean (settings, "unar-open-zip", FALSE);
+
+	g_object_unref (settings);
+
 	return sevenz_mime_types;
 }
 
