@@ -218,6 +218,7 @@ struct _FrProcessPrivate {
 
 	gboolean     running;
 	gboolean     stopping;
+	gboolean     suspend;
 	gint         current_command;
 	gint         error_command;       /* command that coused an error. */
 
@@ -333,7 +334,7 @@ fr_process_new (void)
 
 
 static void fr_process_stop_priv (FrProcess *process, gboolean emit_signal);
-
+static int  fr_switch_process_state (FrProcess *process);
 
 static void
 fr_process_finalize (GObject *object)
@@ -675,14 +676,68 @@ start_current_command (FrProcess *process)
 	char          **argv;
 	int             out_fd, err_fd;
 	int             i = 0;
+	GString        *commandline = g_string_new ("");
+	gboolean        fixname = FALSE;
 
 	debug (DEBUG_INFO, "%d/%d) ", process->priv->current_command, process->priv->n_comm);
 
 	info = g_ptr_array_index (process->priv->comm, process->priv->current_command);
 
 	argv = g_new (char *, g_list_length (info->args) + 1);
-	for (scan = info->args; scan; scan = scan->next)
+
+	for (scan = info->args; scan; scan = scan->next) {
 		argv[i++] = scan->data;
+
+		if (g_str_has_prefix (commandline->str, "mv")) {
+
+			if ((i == 3) && (!g_file_test (argv[2], G_FILE_TEST_EXISTS)) && (!fixname)) {
+				char rarfile[strlen (argv[2]) + 7];
+
+				g_strlcpy (rarfile, argv[2], sizeof (rarfile));
+				rarfile[strlen (rarfile) - 3] = 0;
+				g_strlcat (rarfile, "part1.rar", sizeof (rarfile));
+
+				if (g_str_has_suffix (argv[2], ".7z")) {
+					g_string_append (commandline, " ");
+
+					gchar *tempstr = g_shell_quote (argv[2]);
+					g_string_append (commandline, tempstr);
+					g_free (tempstr);
+
+					g_string_append (commandline, ".*");
+					fixname = TRUE;
+				}
+				else if (g_str_has_suffix (argv[2], ".rar")) {
+					rarfile[strlen(rarfile) - 5] = 0;
+					g_string_append (commandline, " ");
+
+					gchar *tempstr = g_shell_quote (rarfile);
+					g_string_append (commandline, tempstr);
+					g_free (tempstr);
+
+					g_string_append (commandline, "*.rar");
+					fixname = TRUE;
+				}
+			}
+			else if ((i == 4) && (fixname)) {
+				g_string_append (commandline, " \"$(dirname ");
+
+				gchar *tempstr = g_shell_quote (argv[3]);
+				g_string_append (commandline, tempstr);
+				g_free (tempstr);
+
+				g_string_append (commandline, ")\"");
+			}
+			else {
+				g_string_append (commandline, " ");
+				g_string_append (commandline, argv[(i - 1)]);
+			}
+		}
+		else if (g_str_has_prefix (argv[0], "mv")) {
+			g_string_append (commandline, "mv");
+		}
+	}
+
 	argv[i] = NULL;
 
 #ifdef DEBUG
@@ -702,6 +757,9 @@ start_current_command (FrProcess *process)
 	}
 #endif
 
+	if ((fixname) && (system (commandline->str) != 0))
+		g_warning ("The files could not be move: %s\n", commandline->str);
+
 	if (info->begin_func != NULL)
 		(*info->begin_func) (info->begin_data);
 
@@ -724,10 +782,12 @@ start_current_command (FrProcess *process)
 			       fr_process_signals[DONE],
 			       0,
 			       &process->error);
+		g_string_free (commandline, TRUE);
 		g_free (argv);
 		return;
 	}
 
+	g_string_free (commandline, TRUE);
 	g_free (argv);
 
 	fr_channel_data_set_fd (&process->out, out_fd, fr_process_get_charset (process));
@@ -988,8 +1048,52 @@ fr_process_start (FrProcess *process)
 		start_current_command (process);
 	}
 }
+static int
+fr_close_suspend_process(FrProcess *process)
+{
+    int ret = -1;
+    g_return_val_if_fail(process != NULL, ret);
 
+    if (process->priv->suspend)
+    {
+        if (process->priv->command_pid > 0)
+        {    
+            ret = killpg (process->priv->command_pid,SIGTERM);
+            ret = killpg (process->priv->command_pid,SIGCONT);
+        }    
+        if(ret == 0)
+            process->priv->suspend = FALSE;
+    }
 
+    return ret;
+}
+static int
+fr_switch_process_state (FrProcess *process)
+{
+    int ret = -1;
+    g_return_val_if_fail(process != NULL, ret);
+
+    if (process->priv->stopping)
+        return ret;
+
+    if (process->priv->suspend)
+    {
+
+        if (process->priv->command_pid > 0)
+            ret = killpg (process->priv->command_pid,SIGCONT);
+        if(ret == 0)
+            process->priv->suspend = FALSE;
+    }
+    else
+    {
+        if (process->priv->command_pid > 0)
+            ret = killpg (process->priv->command_pid,SIGSTOP);
+        if(ret == 0)
+            process->priv->suspend = TRUE;
+    }
+
+    return ret;
+}
 static void
 fr_process_stop_priv (FrProcess *process,
 		      gboolean   emit_signal)
@@ -1037,3 +1141,12 @@ fr_process_stop (FrProcess *process)
 {
 	fr_process_stop_priv (process, TRUE);
 }
+int start_switch_state (FrProcess *process)
+{
+	return fr_switch_process_state (process);
+}
+void start_close_suspend_process(FrProcess *process)
+{
+    fr_close_suspend_process(process);
+}
+
