@@ -30,7 +30,7 @@
 int         _gtk_count_selected             (GtkTreeSelection *selection);
 GtkWidget*  _gtk_message_dialog_new         (GtkWindow        *parent,
 					     GtkDialogFlags    flags,
-					     const char       *stock_id,
+					     const char       *icon_name,
 					     const char       *message,
 					     const char       *secondary_message,
 					     const char       *first_button_text,
